@@ -80,8 +80,6 @@ class ResponseMixin:
 
                 # If return value is a werkzeug BaseResponse, return it
                 if isinstance(result_raw, BaseResponse):
-                    set_status_and_headers_in_response(
-                        result_raw, status, headers)
                     return result_raw
 
                 # Dump result with schema if specified
@@ -157,9 +155,10 @@ class ResponseMixin:
         return data
 
     @staticmethod
-    def _prepare_response_doc(doc, doc_info, spec, **kwargs):
-        operation = doc_info.get('response', {})
-        for response in operation.get('responses', {}).values():
-            prepare_response(response, spec, DEFAULT_RESPONSE_CONTENT_TYPE)
-        doc = deepupdate(doc, operation)
+    def _prepare_response_doc(doc, doc_info, *, spec, **kwargs):
+        operation = doc_info.get('response')
+        if operation:
+            for response in operation['responses'].values():
+                prepare_response(response, spec, DEFAULT_RESPONSE_CONTENT_TYPE)
+            doc = deepupdate(doc, operation)
         return doc
